Arena

Struct Arena 

pub struct Arena { /* private fields */ }

Implementations

Source

impl Arena

pub fn with<F, R>(f: F) -> R
where F: for<'a> FnOnce(&'a Arena) -> R,

Invoke the callback function with a reference to a local Arena.

The arena will be dropped when the callback returns.

pub fn alloc_token<T>(&self, value: T) -> &mut T
where T: Token,

pub fn alloc_context<'input, 'a, T>(&'a self, value: T) -> &'a mut T
where T: RuleNode<'input, 'a>, 'input: 'a,

pub fn alloc_exception<'a, T>(&'a self, value: T) -> Box<'a, T>

pub fn alloc_payload<T>(&self, value: T) -> &mut T

pub fn alloc<T>(&self, value: T) -> &mut T