BailErrorStrategy

Struct BailErrorStrategy 

pub struct BailErrorStrategy<'input, 'arena, TF, P>(/* private fields */)
where
    TF: TokenFactory<'input, 'arena> + 'arena,
    P: Parser<'input, 'arena, TF>,
    'input: 'arena;
This implementation of ANTLRErrorStrategy responds to syntax errors by immediately canceling the parse operation with a ParseCancellationException. The implementation ensures that the ParserRuleContext.exception field is set for all parse tree nodes that were not completed prior to encountering the error.

This error strategy is useful in the following scenarios.

  • Two-stage parsing: This error strategy allows the first stage of two-stage parsing to immediately terminate if an error is encountered, and immediately fall back to the second stage. In addition to avoiding wasted work by attempting to recover from errors here, the empty implementation of sync improves the performance of the first stage.
  • Silent validation: When syntax errors are not being reported or logged, and the parse result is simply ignored if errors occur, the BailErrorStrategy avoids wasting work on recovering from errors when the result will be ignored either way.

Usage

use dbt_antlr4::error_strategy::BailErrorStrategy;
myparser.err_handler = BailErrorStrategy::new();

*/

Implementations

Source

impl<'input, 'arena, TF, P> BailErrorStrategy<'input, 'arena, TF, P>
where TF: TokenFactory<'input, 'arena> + 'arena, P: Parser<'input, 'arena, TF>, 'input: 'arena,

pub fn new() -> Self

Creates new instance of BailErrorStrategy