pub struct BaseLexer<'input, 'arena, Ext, Input, TF>where
Ext: LexerRecog<'input, 'arena, TF, Self> + 'static,
Input: CharStream<'input>,
TF: TokenFactory<'input, 'arena> + 'arena,
'input: 'arena,{
pub interpreter: Option<Box<LexerATNSimulator>>,
pub input: Option<Input>,
pub token_start_char_index: isize,
pub token_start_line: u32,
pub token_start_column: i32,
pub token_type: i32,
pub token: Option<&'arena mut TF::Tok>,
pub channel: i32,
pub mode_stack: Vec<usize>,
pub mode: usize,
pub text: Option<String>,
/* private fields */
}Expand description
Default implementation of Lexer
Public fields in this struct are intended to be used by embedded actions
Fields
interpreter: Option<Box<LexerATNSimulator>>LexerATNSimulator instance of this lexer
input: Option<Input>CharStream used by this lexer
token_start_char_index: isizetoken_start_line: u32token_start_column: i32token_type: i32Overrides token type emitted by lexer for current token
token: Option<&'arena mut TF::Tok>Make it Some to override token that is currently being generated by lexer
channel: i32Channel lexer is currently assigning tokens to
mode_stack: Vec<usize>stack of modes, which is used for pushMode,popMode lexer actions
mode: usizeMode lexer is currently in
text: Option<String>Make it Some to override text for token that is currently being generated by lexer
Implementations
Sourceimpl<'input, 'arena, Ext, Input, TF> BaseLexer<'input, 'arena, Ext, Input, TF>where
Ext: LexerRecog<'input, 'arena, TF, Self> + 'static,
Input: CharStream<'input>,
TF: TokenFactory<'input, 'arena> + 'arena,
'input: 'arena,
impl<'input, 'arena, Ext, Input, TF> BaseLexer<'input, 'arena, Ext, Input, TF>where
Ext: LexerRecog<'input, 'arena, TF, Self> + 'static,
Input: CharStream<'input>,
TF: TokenFactory<'input, 'arena> + 'arena,
'input: 'arena,
Sourcepub fn get_char_index(&self) -> isize
pub fn get_char_index(&self) -> isize
Current position in input stream
Sourcepub fn set_text(&mut self, _text: impl Into<String>)
pub fn set_text(&mut self, _text: impl Into<String>)
Used from lexer actions to override text of the token that will be emitted next
Sourcepub fn add_error_listener(
&mut self,
listener: Box<dyn ErrorListener<'input, 'arena, Self>>,
)
pub fn add_error_listener( &mut self, listener: Box<dyn ErrorListener<'input, 'arena, Self>>, )
Add error listener
Sourcepub fn remove_error_listeners(&mut self)
pub fn remove_error_listeners(&mut self)
Remove and drop all error listeners
Sourcepub fn new_base_lexer(input: Input, recog: Ext, factory: TF) -> Self
pub fn new_base_lexer(input: Input, recog: Ext, factory: TF) -> Self
Creates new lexer instance