TreeNode

Struct TreeNode 

pub struct TreeNode<'input, 'arena, NodeKind, Tok = CommonToken<'input>>
where NodeKind: NodeKindType<'arena, Tok>, Tok: Token + 'input, 'input: 'arena,
{ pub node_tag: NodeKind, /* private fields */ }

Fields

node_tag: NodeKind

Implementations

Source

impl<'input, 'arena, NodeKind, Tok> TreeNode<'input, 'arena, NodeKind, Tok>
where NodeKind: NodeKindType<'arena, Tok>, Tok: Token + 'input, 'input: 'arena,

pub fn create_token_node(arena: &'arena Arena, symbol: &'arena Tok) -> *mut Self

pub fn create_error_node(arena: &'arena Arena, symbol: &'arena Tok) -> *mut Self

pub fn node_tag(&self) -> NodeKind

pub fn get_rule_context(&self) -> &dyn ParserRuleContext<'input, 'arena>

Return the ParserRuleContext object associated with this rule node.

pub fn get_rule_context_mut( &mut self, ) -> &mut dyn ParserRuleContext<'input, 'arena>

Return mutable reference to the ParserRuleContext object associated with this rule node.

pub fn ctx_ptr(&self) -> CtxPtr<'input, 'arena>

pub fn as_rule_context<T>(&self) -> Option<&T>
where T: ParserRuleContext<'input, 'arena> + NodeInner<'input, 'arena, NodeKind, Tok>,

Attempt to downcast this node to specific ParserRuleContext type

pub fn as_rule_context_mut<T>(&mut self) -> Option<&mut T>
where T: ParserRuleContext<'input, 'arena> + NodeInner<'input, 'arena, NodeKind, Tok>,

Attempt to downcast this node to specific ParserRuleContext type

pub fn as_terminal_node(&self) -> Option<&TerminalNode<'input, 'arena, Tok>>

Downcast this node to terminal node, if the associated context is a terminal node

pub fn as_terminal_node_mut( &mut self, ) -> Option<&mut TerminalNode<'input, 'arena, Tok>>

Downcast this node to terminal node, if the associated context is a terminal node

pub fn as_error_node(&self) -> Option<&ErrorNode<'input, 'arena, Tok>>

Downcast this node to error node, if the associated context is an error node

pub fn as_error_node_mut( &mut self, ) -> Option<&mut ErrorNode<'input, 'arena, Tok>>

Downcast this node to error node, if the associated context is an error node

pub fn set_exception(&self, _e: ANTLRError, _arena: &'arena Arena)

pub fn set_invoking_state(&mut self, s: i32)

Sets internal parser state

pub fn set_alt_number(&mut self, _alt_number: i32)

pub fn set_start(&mut self, t: Option<&'arena Tok>)

pub fn set_stop(&mut self, t: Option<&'arena Tok>)

pub fn remove_last_child(&mut self)

pub fn add_child(&mut self, _child: &'arena Self)

pub fn set_parent(&mut self, parent: Option<&'arena Self>)

pub fn enter_rule( &self, listener: &mut NodeKind::Listener, ) -> Result<(), ANTLRError>

pub fn exit_rule( &self, listener: &mut NodeKind::Listener, ) -> Result<(), ANTLRError>