pub struct InputStream<'input> { /* private fields */ }Expand description
Default rust target input stream.
Since Rust uses UTF-8 format which does not support indexing by char,
InputStream<&str> has slightly different index behavior in compare to java runtime when there are
non-ASCII unicode characters.
If you need it to generate exactly the same indexes as Java runtime, you have to use CodePoint8/16/32BitCharStream,
which does not use rusts native str type, so it would do additional conversions and allocations along the way.
Implementations